Road Map — django-frontend-skeleton 1.2.0 documentation

### Navigation

- index
- previous |
- django-frontend-skeleton 1.2.0 documentation »

# Road Map

## 1.*.0

- Use Git submodules for external libraries.

### Table Of Contents

- Road Map
  - 1.*.0

#### Previous topic

Changelog

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- previous |
- django-frontend-skeleton 1.2.0 documentation »

© Copyright 2013, Jon Faustman. Created using Sphinx 1.1.3.